"use client";

import React, { useEffect, useState } from 'react';
import Link from 'next/link';

interface YouTubeVideo {
  id: string;
  title: string;
  country: string;
}

interface RelatedAfricanMoviesProps {
  videoId: string;
}

const RelatedAfricanMovies: React.FC<RelatedAfricanMoviesProps> = ({ videoId }) => {
  const [relatedVideos, setRelatedVideos] = useState<YouTubeVideo[]>([]);
  const [itemsToShow, setItemsToShow] = useState(40);
  const [fadeKey, setFadeKey] = useState(0);

  useEffect(() => {
    const calculateItemsToShow = () => {
      const screenWidth = window.innerWidth;
      if (screenWidth >= 1024) {
        setItemsToShow(40); // 40 items for PC
      } else if (screenWidth >= 768) {
        setItemsToShow(24); // Adjusted for tablets (e.g., 4 rows with 6 items each)
      } else {
        setItemsToShow(21); // 21 items for mobile
      }
    };

    calculateItemsToShow();
    window.addEventListener('resize', calculateItemsToShow);

    return () => {
      window.removeEventListener('resize', calculateItemsToShow);
    };
  }, []);

  useEffect(() => {
    const fetchRelatedVideos = async () => {
      try {
        const response = await fetch('/data/african.json');
        const data = await response.json();

        // Filter out the current video from the list of related videos
        const relatedVideos = data.filter((video: YouTubeVideo) => video.id !== videoId);
        setRelatedVideos(relatedVideos.slice(0, itemsToShow));
      } catch (error) {
        console.error('Failed to fetch related videos:', error);
      }
    };

    fetchRelatedVideos();
    setFadeKey((prevKey) => prevKey + 1);
  }, [videoId, itemsToShow]);

  return (
    <div className="relative mt-12">
      <h2 className="text-white text-2xl font-orbitron mb-6 pl-4">You May Also Like</h2>
      <div
        key={fadeKey}
        className="grid grid-cols-3 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-5 xl:grid-cols-8 gap-4 px-2 md:px-4 animate-fadeIn mb-20 md:mb-8"
      >
        {relatedVideos.map((video) => (
          <Link key={video.id} href={`/watch/afriq?videoId=${video.id}`} passHref>
            <div className="relative cursor-pointer animate-filter group">
              {/* Blurred background layer within the thumbnail container */}
              <div className="absolute inset-0 w-full h-full rounded-lg overflow-hidden">
                <img
                  src={`https://img.youtube.com/vi/${video.id}/hqdefault.jpg`} // Fetching the thumbnail from YouTube
                  alt={video.title}
                  className="w-full h-full object-cover filter blur-md transform scale-150" // Scaling the background up
                />
              </div>

              {/* Foreground image, centered and fitting within the container */}
              <div className="relative z-10 flex justify-center items-center h-[180px] md:h-[280px]">
                <img
                  src={`https://img.youtube.com/vi/${video.id}/hqdefault.jpg`} // Fetching the thumbnail from YouTube
                  alt={video.title}
                  className="max-w-full max-h-full object-contain rounded-lg shadow-lg transition-transform duration-300 ease-in-out transform group-hover:scale-105"
                />
              </div>

              {/* Country flag */}
              <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-xs px-2 py-1 rounded flex items-center z-20">
                <img
                  src={`/flags/${video.country.toLowerCase()}.png`} // Fetching the flag image
                  alt={video.country}
                  className="w-6 h-4 mr-2"
                />
                {video.country}
              </div>
            </div>
          </Link>
        ))}
      </div>

      <style jsx>{`
        .animate-fadeIn {
          animation: fadeIn 1s ease-in-out;
        }

        .animate-filter {
          animation: filter 0.5s ease-in-out;
        }

        @keyframes fadeIn {
          from {
            opacity: 0;
            transform: translateY(20px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes filter {
          from {
            opacity: 0.5;
            transform: scale(0.95);
          }
          to {
            opacity: 1;
            transform: scale(1);
          }
        }
      `}</style>
    </div>
  );
};

export default RelatedAfricanMovies;
